==> ihaskell-0.12.0.0-43-x86_64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ihaskell
version:              0.12.0.0
visibility:           public
id:                   ihaskell-0.12.0.0-HJHQU77YBWZGw7pqcxnd5y
key:                  ihaskell-0.12.0.0-HJHQU77YBWZGw7pqcxnd5y
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  9b9b07ae8da19e02369ba5cc73e23ef5
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Evaluate.HTML IHaskell.Eval.Hoogle IHaskell.Eval.Info
    IHaskell.Eval.Inspect IHaskell.Eval.Lint IHaskell.Eval.ParseShell
    IHaskell.Eval.Parser IHaskell.Eval.Util IHaskell.Eval.Widgets
    IHaskell.Flags IHaskell.IPython IHaskell.IPython.Stdin
    IHaskell.Publish IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.12.0.0-HJHQU77YBWZGw7pqcxnd5y
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1
    base64-bytestring-1.2.1.0-7XHgmf0PZMy7LO91awCYGH binary-0.8.9.1
    bytestring-0.11.5.3 cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-parser-0.2.7.0-KIzcyN5x3OS2vnff2gcb1T
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-syntax-highlighter-0.0.9.0-KajgC8uzDQPEjKqXEOtoO5
    haskeline-0.8.2 hlint-3.5-3gNxa88RiLDGr0GW9zMe11
    http-client-0.7.19-GGFMm7MPmy6D22PtCWjSH6
    http-client-tls-0.3.6.4-SlbGxNbffj8iOCf5aZg59
    ipython-kernel-0.11.0.0-5mmNCNVOzkjBFjtc0oOBuj parsec-3.1.16.1
    process-1.6.18.0 random-1.2.1.3-1e4k6oKN9kc4OrDtxhM2uQ
    shelly-1.11.0-35O2WDRB0boFbt1816K7X0
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV stm-2.5.1.0
    strict-0.5-3YqyrbNmr9gBQeoCoaFr88 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15
    vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> ihaskell-0.12.0.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ihaskell
version:              0.12.0.0
visibility:           public
id:                   ihaskell-0.12.0.0-L825IHdl4cKKyJgJBGY5gL
key:                  ihaskell-0.12.0.0-L825IHdl4cKKyJgJBGY5gL
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  21068dd3025ec604d86e9ca0dbce246a
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Evaluate.HTML IHaskell.Eval.Hoogle IHaskell.Eval.Info
    IHaskell.Eval.Inspect IHaskell.Eval.Lint IHaskell.Eval.ParseShell
    IHaskell.Eval.Parser IHaskell.Eval.Util IHaskell.Eval.Widgets
    IHaskell.Flags IHaskell.IPython IHaskell.IPython.Stdin
    IHaskell.Publish IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.12.0.0-L825IHdl4cKKyJgJBGY5gL
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1
    base64-bytestring-1.2.1.0-7XHgmf0PZMy7LO91awCYGH binary-0.8.9.1
    bytestring-0.11.5.3 cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-parser-0.2.7.0-KIzcyN5x3OS2vnff2gcb1T
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-syntax-highlighter-0.0.9.0-KajgC8uzDQPEjKqXEOtoO5
    haskeline-0.8.2 hlint-3.5-3gNxa88RiLDGr0GW9zMe11
    http-client-0.7.19-HKufh1jjwuP9GgoT1daAYk
    http-client-tls-0.3.6.4-LgxEH4AYXpUIPSbTePRf53
    ipython-kernel-0.11.0.0-5mmNCNVOzkjBFjtc0oOBuj parsec-3.1.16.1
    process-1.6.18.0 random-1.2.1.3-1e4k6oKN9kc4OrDtxhM2uQ
    shelly-1.11.0-35O2WDRB0boFbt1816K7X0
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV stm-2.5.1.0
    strict-0.5-3YqyrbNmr9gBQeoCoaFr88 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15
    vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
